@@ -1,13 +1,18 @@
+package PerlIO::excl;
+use strict;
 require PerlIO::Util;
+1;
 __END__
 
+=encoding utf-8
+
 =head1 NAME
 
 PerlIO::excl - Creates a file only if it doesn't exist
 
 =head1 SYNOPSIS
 
-	open my $io,  '+<:excl', $file;
+	open my $io,  '+<:excl', 'foo.txt';
 
 =head1 DESCRIPTION
 
@@ -26,9 +31,9 @@ L<perlfunc/sysopen>.
 
 =head1 AUTHOR
 
-Goro Fuji E<lt>gfuji (at) cpan.orgE<gt>
+Goro Fuji (藤 吾郎) E<lt>gfuji (at) cpan.orgE<gt>
 
-=head1 LICENCE AND COPYRIGHT
+=head1 LICENSE AND COPYRIGHT
 
 Copyright (c) 2008, Goro Fuji E<lt>gfuji (at) cpan.orgE<gt>. Some rights reserved.
 
